adjust_lambda: Adjust Lambda

View source: R/adjust_lambda.R

adjust_lambdaR Documentation

Adjust Lambda

Description

Adjust Lambda

Usage

adjust_lambda(design, ...)

Arguments

design

An object created with one of the setup functions.

...

Further arguments.

Details

The default method for adjust_lambda uses a combination of uniroot and grid search and calls toer in every iteration. For methods implemented in the bhmbasket package there are separate methods that are computationally more efficient.

Value

A list containing the greatest estimated value for lambda with prec_digits decimal places which controls the family wise error rate at level alpha (one-sided) and the estimated family wise error rate for the estimated lambda.

Examples


design <- setup_cpp(k = 3, p0 = 0.2)

# Equal sample sizes
adjust_lambda(design = design, n = 20, alpha = 0.05,
  design_params = list(tune_a = 1, tune_b = 1), iter = 1000)

# Unequal sample sizes
adjust_lambda(design = design, n = c(15, 20, 25), alpha = 0.05,
   design_params = list(tune_a = 1, tune_b = 1), iter = 1000)


basksim documentation built on May 12, 2026, 9:08 a.m.