View source: R/adjust_lambda.R
| adjust_lambda.default | R Documentation |
Adjust Lambda
## Default S3 method:
adjust_lambda(
design,
n,
p1 = NULL,
alpha = 0.05,
design_params = list(),
iter = 1000,
prec_digits = 3,
data = NULL,
...
)
design |
An object created with one of the |
n |
The sample sizes of the baskets. A vector must be used for varying sample sizes. |
p1 |
Probabilities under the alternative hypothesis. If |
alpha |
The one-sided significance level. |
design_params |
A list of params that is specific to the class of
|
iter |
The number of iterations in the simulation. Is ignored if
|
prec_digits |
Number of decimal places that are considered when adjusting lambda. |
data |
A data matrix with k column with the number of responses for each
basket. Has to be generated with |
... |
Further arguments. |
It is recommended to use data and then use the same simulated
data set for all further calculations. If data = NULL then
new data are generated in each step of the algorithm, so lambda doesn't
necessarily protect the family wise error rate for different simulated data
due to Monte Carlo simulation error.
A list containing the greatest estimated value for lambda with
prec_digits decimal places which controls the family wise error rate
at level alpha (one-sided) and the estimated family wise error rate
for the estimated lambda.
# Example for a basket trial with Fujikawa's Design
design <- setup_fujikawa(k = 3, p0 = 0.2)
# Equal sample sizes
adjust_lambda(design = design, n = 20, alpha = 0.05,
design_params = list(epsilon = 2, tau = 0), iter = 1000)
# Unequal sample sizes
adjust_lambda(design = design, n = c(15, 20, 25), alpha = 0.05,
design_params = list(epsilon = 2, tau = 0), iter = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.