| basksim-package | R Documentation |
Provides a unified syntax for the simulation-based comparison of different single-stage basket trial designs with a binary endpoint and equal sample sizes in all baskets. Methods include the designs by Baumann et al. (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/19466315.2024.2402275")}, Schmitt and Baumann (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/19466315.2025.2486231")}, Fujikawa et al. (2020) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/bimj.201800404")}, Berry et al. (2020) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/1740774513497539")}, and Neuenschwander et al. (2016) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/pst.1730")}. For the latter two designs, the functions are mostly wrappers for functions provided by the package 'bhmbasket'.
Maintainer: Lukas Baumann baumann@imbi.uni-heidelberg.de (ORCID)
Authors:
Lukas D Sauer sauer@imbi.uni-heidelberg.de (ORCID)
Sabrina Schmitt sabrina.schmitt@uni-wuerzburg.de (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.