| get_details | R Documentation |
Get Details of a Basket Trial Simulation
get_details(design, ...)
design |
An object created with one of the |
... |
Further arguments. |
A list containing the rejection probabilities, posterior means, mean squared errors of all baskets and the family-wise error rate. For some methods the mean limits of HDI intervals are also returned.
# Example for a basket trial with Fujikawa's Design
design <- setup_fujikawa(k = 3, p0 = 0.2)
# Equal sample sizes
get_details(design = design, n = 20, p1 = c(0.2, 0.5, 0.5),
lambda = 0.95, epsilon = 2, tau = 0, iter = 100)
# Unequal sample sizes
get_details(design = design, n = c(15, 20, 25),
p1 = c(0.2, 0.5, 0.5), lambda = 0.95, epsilon = 2,
tau = 0, iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.