get_details.binomial: Get Details of a Basket Trial with the Frequentist Binomial...

View source: R/get_details.R

get_details.binomialR Documentation

Get Details of a Basket Trial with the Frequentist Binomial Design

Description

This basic frequentist design conducts a separate binomial test for each basket. All tests are one-sided, and the alternative is greater than the null hypothesis. These details are calculated exactly, not simulated.

Usage

## S3 method for class 'binomial'
get_details(design, n, p1 = NULL, alpha = 0.025, ...)

Arguments

design

An object of class binomial.

n

The sample sizes of the baskets. A vector must be used for varying sample sizes.

p1

Probabilities used for the simulation. If NULL then all probabilities are set to p0.

alpha

The one-sided significance level.

...

Further arguments.

Value

A list containing the rejection probabilities, critical values and expected number of correct decisions. Critical values c are defined so that the null hypothesis is rejected if the observed number of responses r is greater than c, i.e. r > c rejects H_0. The nominal FWER is the (theoretical) FWER of a multiple testing problem with k hypothesis tests at significance level \alpha. The actual FWER is usually lower than the nominal FWER, as the binomial test does not exhaust its significance level.

Examples

design <- setup_binomial(k = 3, p0 = 0.2)
p1 <- c(0.2, 0.5, 0.5)
get_details(design = design, n = 20, p1 = p1)

basksim documentation built on May 12, 2026, 9:08 a.m.