| get_details.exnex | R Documentation |
Get Details of a Basket Trial Simulation with the EXNEX Design
## S3 method for class 'exnex'
get_details(
design,
n,
p1 = NULL,
lambda,
level = 0.95,
tau_scale,
w_j,
iter = 1000,
n_mcmc = 10000,
data = NULL,
...
)
design |
An object of class |
n |
The sample sizes of the baskets. A vector must be used for varying sample sizes. |
p1 |
Probabilities used for the simulation. If |
lambda |
The posterior probability threshold. |
level |
Level of the credibility intervals. |
tau_scale |
Standard deviation of the half normal prior exchangeability distribution for the variance of the thetas. |
w_j |
Fixed prior weight for the exchangeability part of the model. |
iter |
The number of iterations in the simulation. Is ignored if
|
n_mcmc |
Number of MCMC samples. |
data |
An object of class |
... |
Further arguments. |
A list containing the rejection probabilities, posterior means, mean squared errors and mean limits of HDI intervals for all baskets as well as the family-wise error rate.
design <- setup_exnex(k = 3, p0 = 0.2)
# Equal sample sizes
get_details(design = design, n = 20, p1 = c(0.2, 0.5, 0.5),
lambda = 0.95, tau_scale = 1, w_j = 0.5, iter = 100)
# Unequal sample sizes
get_details(design = design, n = c(15, 20, 25), p1 = c(0.2, 0.5, 0.5),
lambda = 0.95, tau_scale = 1, w_j = 0.5, iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.