View source: R/get_evaluation.R
| get_evaluation | R Documentation |
Evaluate a Basket Trial
get_evaluation(design, ...)
design |
An object created with one of the |
... |
Further arguments. |
A list containing the point estimates of the basket-specific response rates and, for some methods, the posterior probabilities that the estimated response rates are above a specified threshold p0.
# Example for a basket trial with Fujikawa's Design
design <- setup_fujikawa(k = 3, p0 = 0.2)
# Equal sample sizes
get_evaluation(design = design, n = 20, r = c(10, 15, 5),
lambda = 0.95, epsilon = 2, tau = 0, iter = 100)
# Unequal sample sizes
get_evaluation(design = design, n = c(15, 20, 25),
r = c(10, 15, 17), lambda = 0.95, epsilon = 2,
tau = 0, iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.