Learn R Programming

basksim (version 2.0.2)

get_evaluation.app: Evaluate a Basket Trial with the Adaptive Power Prior Design for sequential clinical trials

Description

Evaluate a Basket Trial with the Adaptive Power Prior Design for sequential clinical trials

Usage

# S3 method for app
get_evaluation(design, n, r, lambda, level = 0.95, ...)

Value

A list containing the point estimates of the basket-specific response rates and the posterior probabilities that the estimated response rates are above a specified threshold p0.

Arguments

design

An object of class app.

n

The sample sizes of the baskets. A vector must be used for varying sample sizes.

r

Vector of responses.

lambda

The posterior probability threshold.

level

Level of the credibility intervals.

...

Further arguments.

Examples

Run this code
design <- setup_app(k = 3, p0 = 0.2)

# Equal sample sizes
get_evaluation(design = design, n = 20, r = c(10, 15, 5),
 lambda = 0.95, iter = 100)

# Unequal sample sizes
get_evaluation(design = design, n = c(15, 20, 25), r = c(10, 15, 17),
 lambda = 0.95, iter = 100)

Run the code above in your browser using DataLab