View source: R/get_evaluation.R
| get_evaluation.bhm | R Documentation |
Evaluate a BHM Basket Trial
## S3 method for class 'bhm'
get_evaluation(
design,
n,
r,
lambda,
level = 0.95,
tau_scale,
n_mcmc = 10000,
...
)
design |
An object of class |
n |
The sample sizes of the baskets. A vector must be used for varying sample sizes. |
r |
Vector of responses. |
lambda |
The posterior probability threshold. |
level |
Level of the credibility intervals. |
tau_scale |
Standard deviation of the half normal prior distribution for the variance of the thetas. |
n_mcmc |
Number of MCMC samples. |
... |
Further arguments. |
A list containing the point estimates of the basket-specific response rates.
design <- setup_bhm(k = 3, p0 = 0.2, p_target = 0.5)
get_evaluation(design = design, n = c(20, 20, 20), r = c(10, 15, 5),
lambda = 0.95, tau_scale = 1, iter = 100)
# Unequal sample sizes
get_evaluation(design = design, n = c(15, 20, 25), r = c(10, 15, 17),
lambda = 0.95, tau_scale = 1, iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.