View source: R/get_evaluation.R
| get_evaluation.cpplim | R Documentation |
Evaluate a Basket Trial with the Limited Calibrated Power Prior Design
## S3 method for class 'cpplim'
get_evaluation(design, n, r, lambda, level = 0.95, tune_a, tune_b, ...)
design |
An object of class |
n |
The sample sizes of the baskets. A vector must be used for varying sample sizes. |
r |
Vector of responses. |
lambda |
The posterior probability threshold. |
level |
Level of the credibility intervals. |
tune_a |
First tuning parameter that determines the amount of borrowing based on pairwise similarity between baskets. |
tune_b |
Second tuning parameter that determines the amount of borrowing based on pairwise similarity between baskets. |
... |
Further arguments. |
A list containing the point estimates of the basket-specific response rates and the posterior probabilities that the estimated response rates are above a specified threshold p0.
design <- setup_cpplim(k = 3, p0 = 0.2)
# Equal sample sizes
get_evaluation(design = design, n = 20, r = c(10, 15, 5),
lambda = 0.95, tune_a = 1, tune_b = 1, iter = 100)
# Unequal sample sizes
get_evaluation(design = design, n = c(15, 20, 25), r = c(10, 15, 17),
lambda = 0.95, tune_a = 1, tune_b = 1, iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.