get_evaluation.exnex: Evaluate a Basket Trial with the EXNEX Design

View source: R/get_evaluation.R

get_evaluation.exnexR Documentation

Evaluate a Basket Trial with the EXNEX Design

Description

Evaluate a Basket Trial with the EXNEX Design

Usage

## S3 method for class 'exnex'
get_evaluation(
  design,
  n,
  r,
  lambda,
  level = 0.95,
  tau_scale,
  w_j,
  n_mcmc = 10000,
  ...
)

Arguments

design

An object of class exnex.

n

The sample sizes of the baskets. A vector must be used for varying sample sizes.

r

Vector of responses.

lambda

The posterior probability threshold.

level

Level of the credibility intervals.

tau_scale

Standard deviation of the half normal prior exchangeability distribution for the variance of the thetas.

w_j

Fixed prior weight for the exchangeability part of the model.

n_mcmc

Number of MCMC samples.

...

Further arguments.

Value

A list containing the point estimates of the basket-specific response rates.

Examples

design <- setup_exnex(k = 3, p0 = 0.2)

# Equal sample sizes
get_evaluation(design = design, n = c(20, 20, 20), r = c(10, 15, 5),
  lambda = 0.95, tau_scale = 1, w_j = 0.5, iter = 100)

# Unequal sample sizes
get_evaluation(design = design, n = c(15, 20, 25), r = c(10, 15, 17),
  lambda = 0.95, tau_scale = 1, w_j = 0.5, iter = 100)

basksim documentation built on May 12, 2026, 9:08 a.m.