View source: R/get_evaluation.R
| get_evaluation.fujikawa | R Documentation |
Evaluate a Basket Trial with Fujikawa's Design
## S3 method for class 'fujikawa'
get_evaluation(
design,
n,
r,
lambda,
level = 0.95,
epsilon,
tau,
logbase = 2,
...
)
design |
An object of class |
n |
The sample sizes of the baskets. A vector must be used for varying sample sizes. |
r |
Vector of responses. |
lambda |
The posterior probability threshold. |
level |
Level of the credibility intervals. |
epsilon |
Tuning parameter that determines the amount of borrowing.
See |
tau |
Tuning parameter that determines how similar the baskets
have to be that information is shared. See |
logbase |
Tuning parameter. The base of the logarithm that is used to calculate the Jensen-Shannon divergence. |
... |
Further arguments. |
A list containing the point estimates of the basket-specific response rates and the posterior probabilities that the estimated response rates are above a specified threshold p0.
design <- setup_fujikawa(k = 3, p0 = 0.2)
# Equal sample sizes
get_evaluation(design = design, n = 20, r = c(10, 15, 5),
lambda = 0.95, epsilon = 2, tau = 0, iter = 100)
# Unequal sample sizes
get_evaluation(design = design, n = c(15, 20, 25),
r = c(10, 15, 17), lambda = 0.95, epsilon = 2,
tau = 0, iter = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.