| setup_app | R Documentation |
Set Up Adaptive Power Prior Design Object
setup_app(k, p0, shape1 = 1, shape2 = 1)
k |
The number of baskets. |
p0 |
A common probability under the null hypothesis. |
shape1 |
First common shape parameter of the beta prior. |
shape2 |
Second common shape parameter of the beta prior. |
The class app implements the adaptive power prior design for
sequential clinical trials proposed by Ollier et al. (2020).
An S3 object of class app
Ollier, A., Morita, S., Ursino, M., & Zohar, S. (2020). An adaptive power prior for sequential clinical trials - Application to bridging studies. Statistical methods in medical research, 29(8), 2282–2294.
design_app <- setup_app(k = 3, p0 = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.