setup_binomial: Set Up Frequentist Binomial Design Object

View source: R/class.R

setup_binomialR Documentation

Set Up Frequentist Binomial Design Object

Description

Set Up Frequentist Binomial Design Object

Usage

setup_binomial(k, p0, pool = FALSE)

Arguments

k

The number of baskets.

p0

A common probability under the null hypothesis.

pool

A logical, should data from all baskets be pooled? Default is FALSE. Currently FALSE is the only working option, reserved for future implementation.

Details

The class binomial implements a basket trial design, in which each null hypothesis is tested using the frequentist binomial test without multiplicity correction. All baskets are either tested separately (the default) or pooled (not implemented yet).

Value

An S3 object of class binomial

Examples

design_binomial <- setup_binomial(k = 3, p0 = 0.2)

basksim documentation built on May 12, 2026, 9:08 a.m.