setup_cpp: Set Up Calibrated Power Prior Design Object

View source: R/class.R

setup_cppR Documentation

Set Up Calibrated Power Prior Design Object

Description

Set Up Calibrated Power Prior Design Object

Usage

setup_cpp(k, p0, shape1 = 1, shape2 = 1)

Arguments

k

The number of baskets.

p0

A common probability under the null hypothesis.

shape1

First common shape parameter of the beta prior.

shape2

Second common shape parameter of the beta prior.

Details

The class cpp implements a version of the power prior design, in which the amount of information that is shared between baskets is determined by the Kolmogorov-Smirnov test statistic between baskets (which is equivalent to the absolut difference in response rates).

Value

An S3 object of class cpp

References

Baumann, L., Sauer, L. D., & Kieser, M. (2025). A Basket Trial Design Based on Power Priors. Statistics in Biopharmaceutical Research, 17(3), 446–456. https://doi.org/10.1080/19466315.2024.2402275

Examples

design_cpp <- setup_cpp(k = 3, p0 = 0.2)

basksim documentation built on May 12, 2026, 9:08 a.m.