| setup_cppglobal | R Documentation |
Set Up Global Calibrated Power Prior Design Object
setup_cppglobal(k, p0, shape1 = 1, shape2 = 1)
k |
The number of baskets. |
p0 |
A common probability under the null hypothesis. |
shape1 |
First common shape parameter of the beta prior. |
shape2 |
Second common shape parameter of the beta prior. |
The class cppglobal implements a version of the power prior
design, in which the amount of information that is shared between baskets is
determined by the Kolmogorov-Smirnov test statistic between basekts and
a function based on response rate differences that quantifies the
overall heterogeneity.
An S3 object of class cppglobal
Baumann, L., Sauer, L. D., & Kieser, M. (2025). A Basket Trial Design Based on Power Priors. Statistics in Biopharmaceutical Research, 17(3), 446–456. https://doi.org/10.1080/19466315.2024.2402275
design_cppglobal <- setup_cppglobal(k = 3, p0 = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.