setup_jsdglobal: Set Up Global JSD Design Object

View source: R/class.R

setup_jsdglobalR Documentation

Set Up Global JSD Design Object

Description

Set Up Global JSD Design Object

Usage

setup_jsdglobal(k, p0, shape1 = 1, shape2 = 1)

Arguments

k

The number of baskets.

p0

A common probability under the null hypothesis.

shape1

First common shape parameter of the beta prior.

shape2

Second common shape parameter of the beta prior.

Details

The class jsdglobal implements a version of the power prior design, in which information is shared based on pairwise similarity and overall heterogeneity between baskets. Both pairwise similarity and overall heterogeneity are assessed using the Jensen-Shannon divergence.

Value

An S3 object of class jsdglobal

References

Baumann, L., Sauer, L. D., & Kieser, M. (2025). A Basket Trial Design Based on Power Priors. Statistics in Biopharmaceutical Research, 17(3), 446–456. https://doi.org/10.1080/19466315.2024.2402275

Examples

design_jsdglobal <- setup_jsdglobal(k = 3, p0 = 0.2)

basksim documentation built on May 12, 2026, 9:08 a.m.