| get_details.binomial | R Documentation |
This basic frequentist design conducts a separate binomial test for each basket. All tests are one-sided, and the alternative is greater than the null hypothesis. These details are calculated exactly, not simulated.
## S3 method for class 'binomial'
get_details(design, n, p1 = NULL, alpha = 0.025, ...)
design |
An object of class |
n |
The sample sizes of the baskets. A vector must be used for varying sample sizes. |
p1 |
Probabilities used for the simulation. If |
alpha |
The one-sided significance level. |
... |
Further arguments. |
A list containing the rejection probabilities, critical values
and expected number of correct decisions. Critical values c are defined
so that the null hypothesis is rejected if the observed number of responses
r is greater than c, i.e. r > c rejects H_0.
The nominal FWER is the (theoretical) FWER of a multiple testing problem
with k hypothesis tests at significance level \alpha. The actual FWER is
usually lower than the nominal FWER, as the binomial test does not exhaust
its significance level.
design <- setup_binomial(k = 3, p0 = 0.2)
p1 <- c(0.2, 0.5, 0.5)
get_details(design = design, n = 20, p1 = p1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.