Learn R Programming

basksim (version 2.0.2)

get_details.fujikawa: Get Details of a Basket Trial Simulation with Fujikawa's Design

Description

Get Details of a Basket Trial Simulation with Fujikawa's Design

Usage

# S3 method for fujikawa
get_details(
  design,
  n,
  p1 = NULL,
  lambda,
  level = 0.95,
  epsilon,
  tau,
  logbase = 2,
  iter = 1000,
  data = NULL,
  use_future = FALSE,
  weight_fun = NULL,
  weight_params = list(epsilon = epsilon, tau = tau, logbase = logbase),
  ...
)

Value

A list containing the rejection probabilities, posterior means, mean squared errors and mean limits of HDI intervals for all baskets as well as the family-wise error rate and the experiment-wise power.

Arguments

design

An object of class fujikawa.

n

The sample sizes of the baskets. A vector must be used for varying sample sizes.

p1

Probabilities used for the simulation. If NULL then all probabilities are set to p0.

lambda

The posterior probability threshold.

level

Level of the credibility intervals.

epsilon

Tuning parameter that determines the amount of borrowing. See setup_fujikawa).

tau

Tuning parameter that determines how similar the baskets have to be that information is shared. See setup_fujikawa).

logbase

Tuning parameter. The base of the logarithm that is used to calculate the Jensen-Shannon divergence.

iter

The number of iterations in the simulation. Is ignored if data is specified.

data

A data matrix with k column with the number of responses for each basket. Has to be generated with get_data. If data is used, then iter is ignored.

use_future

A logical, should %dofuture% or %do% be used for the call to foreach. Default is FALSE which means that %dofuture% is not used. %dofuture% is needed for parallelization. Note that for actually using parallelized calculations, one needs to activate a future backend.

weight_fun

A function of the form function(design, n, ...) that additionally takes the arguments given in weight_params. If NULL, the original weights suggested by Fujikawa are used (based on the Jensen-Shannon divergence).

weight_params

A named list of input parameters (additional to design and n) for the function weight_fun.

...

Further arguments.

Examples

Run this code
design <- setup_fujikawa(k = 3, p0 = 0.2)

# Equal sample sizes
get_details(design = design, n = 20, p1 = c(0.2, 0.5, 0.5),
  lambda = 0.95, epsilon = 2, tau = 0, iter = 100)

# Unequal sample sizes
get_details(design = design, n = c(15, 20, 25), p1 = c(0.2, 0.5, 0.5),
  lambda = 0.95, epsilon = 2, tau = 0, iter = 100)

# A custom weight function can be defined, e.g.
weight_noshare <- function(design, n, epsilon, tau, logbase){
  n_sum <- n + 1
  return(diag(n_sum))
}
get_details(design = design, n = 20, p1 = c(0.2, 0.5, 0.5), lambda = 0.95,
           epsilon = 2, tau = 0, iter = 1000, weight_fun = weight_noshare)

Run the code above in your browser using DataLab