get_details.fujikawa: Get Details of a Basket Trial Simulation with Fujikawa's Design
Description
Get Details of a Basket Trial Simulation with Fujikawa's Design
Usage
# S3 method for fujikawa
get_details(
design,
n,
p1 = NULL,
lambda,
level = 0.95,
epsilon,
tau,
logbase = 2,
iter = 1000,
data = NULL,
...
)
Value
A list containing the rejection probabilites, posterior means,
mean squared errors and mean limits of HDI intervals for all baskets as well
as the family-wise error rate and the experiment-wise power.
Arguments
design
An object of class fujikawa.
n
The sample size per basket.
p1
Probabilities used for the simulation. If NULL
then all probabilities are set to p0.
lambda
The posterior probability threshold.
level
Level of the credibility intervals.
epsilon
Tuning parameter that determines the amount of borrowing.
See setup_fujikawa).
tau
Tuning parameter that determines how similar the baskets
have to be that information is shared. See setup_fujikawa).
logbase
Tuning parameter. The base of the logarithm that is used to
calculate the Jensen-Shannon divergence.
iter
The number of iterations in the simulation. Is ignored if
data is specified.
data
A data matrix with k column with the number of responses for each
basket. Has to be generated with get_data. If data is used,
then iter is ignored.