Learn R Programming

basksim (version 2.0.2)

setup_app: Setup Adaptive Power Prior Design Object

Description

Setup Adaptive Power Prior Design Object

Usage

setup_app(k, p0, shape1 = 1, shape2 = 1)

Value

An S3 object of class app

Arguments

k

The number of baskets.

p0

A common probability under the null hypothesis.

shape1

First common shape parameter of the beta prior.

shape2

Second common shape parameter of the beta prior.

Details

The class app implements the adaptive power prior design for sequential clinical trials proposed by Ollier et al. (2020).

References

Ollier, A., Morita, S., Ursino, M., & Zohar, S. (2020). An adaptive power prior for sequential clinical trials - Application to bridging studies. Statistical methods in medical research, 29(8), 2282–2294.

Examples

Run this code
design_app <- setup_app(k = 3, p0 = 0.2)

Run the code above in your browser using DataLab