| setup_binomial | R Documentation |
Set Up Frequentist Binomial Design Object
setup_binomial(k, p0, pool = FALSE)
k |
The number of baskets. |
p0 |
A common probability under the null hypothesis. |
pool |
A logical, should data from all baskets be pooled? Default is
|
The class binomial implements a basket trial
design, in which each null hypothesis is tested using the
frequentist binomial test without multiplicity correction. All baskets are
either tested separately (the default) or pooled (not implemented yet).
An S3 object of class binomial
design_binomial <- setup_binomial(k = 3, p0 = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.