| setup_cpplim | R Documentation |
Set Up Limited Calibrated Power Prior Design Object
setup_cpplim(k, p0, shape1 = 1, shape2 = 1)
k |
The number of baskets. |
p0 |
A common probability under the null hypothesis. |
shape1 |
First common shape parameter of the beta prior. |
shape2 |
Second common shape parameter of the beta prior. |
The class cpplim implements a combined version of the adaptive power
prior (app) and the calibrated power prior (cpp), where the
parameter limiting the amount of information to be borrowed in the adaptive
power prior design is included in the calibrated power prior design.
An S3 object of class cpplim
Ollier, A., Morita, S., Ursino, M., & Zohar, S. (2020). An adaptive power prior for sequential clinical trials - Application to bridging studies. Statistical methods in medical research, 29(8), 2282–2294.
Baumann, L., Sauer, L. D., & Kieser, M. (2025). A Basket Trial Design Based on Power Priors. Statistics in Biopharmaceutical Research, 17(3), 446–456. https://doi.org/10.1080/19466315.2024.2402275
design_cpplim <- setup_cpplim(k = 3, p0 = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.