| setup_fujikawa | R Documentation |
Set Up Fujikawa Design Object
setup_fujikawa(k, p0, shape1 = 1, shape2 = 1)
k |
The number of baskets. |
p0 |
A common probability under the null hypothesis. |
shape1 |
First common shape parameter of the beta prior. |
shape2 |
Second common shape parameter of the beta prior. |
The class fujikawa implements a design by Fujikawa et al.
(2020) in which information is shared based on the pairwise similarity
between baskets which is quantified using the Jensen-Shannon divergence
between the individual posterior distributions between baskets.
An S3 object of class fujikawa
Fujikawa, K., Teramukai, S., Yokota, I., & Daimon, T. (2020). A Bayesian basket trial design that borrows information across strata based on the similarity between the posterior distributions of the response probability. Biometrical Journal, 62(2), 330-338.
design_fujikawa <- setup_fujikawa(k = 3, p0 = 0.2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.